@@ -177,29 +177,30 @@ describe('server', () => {
       const fixableDiagnostic = diagnostics.filter(({ code }) => code === 'SC2086')[0]
 
       expect(fixableDiagnostic).toMatchInlineSnapshot(`
-              Object {
-                "code": "SC2086",
-                "codeDescription": Object {
-                  "href": "https://www.shellcheck.net/wiki/SC2086",
-                },
-                "message": "Double quote to prevent globbing and word splitting.",
-                "range": Object {
-                  "end": Object {
-                    "character": 13,
-                    "line": 55,
-                  },
-                  "start": Object {
-                    "character": 5,
-                    "line": 55,
-                  },
-                },
-                "severity": 3,
-                "source": "shellcheck",
-                "tags": undefined,
-              }
-          `)
-
-      // TODO: we could find the diagnostics and then use the range to test the code action
+        Object {
+          "code": "SC2086",
+          "codeDescription": Object {
+            "href": "https://www.shellcheck.net/wiki/SC2086",
+          },
+          "data": Object {
+            "id": "shellcheck|2086|55:5-55:13",
+          },
+          "message": "Double quote to prevent globbing and word splitting.",
+          "range": Object {
+            "end": Object {
+              "character": 13,
+              "line": 55,
+            },
+            "start": Object {
+              "character": 5,
+              "line": 55,
+            },
+          },
+          "severity": 3,
+          "source": "shellcheck",
+          "tags": undefined,
+        }
+      `)
 
       const onCodeAction = connection.onCodeAction.mock.calls[0][0]
 
@@ -560,61 +561,72 @@ describe('server', () => {
 
       // they are all variables
       expect(result).toMatchInlineSnapshot(`
-              Array [
-                Object {
-                  "data": Object {
-                    "type": 3,
-                  },
-                  "documentation": undefined,
-                  "kind": 6,
-                  "label": "BOLD",
-                },
-                Object {
-                  "data": Object {
-                    "type": 3,
-                  },
-                  "documentation": Object {
-                    "kind": "markdown",
-                    "value": "Variable: **RED** - *defined in extension.inc*",
-                  },
-                  "kind": 6,
-                  "label": "RED",
-                },
-                Object {
-                  "data": Object {
-                    "type": 3,
-                  },
-                  "documentation": Object {
-                    "kind": "markdown",
-                    "value": "Variable: **GREEN** - *defined in extension.inc*",
-                  },
-                  "kind": 6,
-                  "label": "GREEN",
-                },
-                Object {
-                  "data": Object {
-                    "type": 3,
-                  },
-                  "documentation": Object {
-                    "kind": "markdown",
-                    "value": "Variable: **BLUE** - *defined in extension.inc*",
-                  },
-                  "kind": 6,
-                  "label": "BLUE",
-                },
-                Object {
-                  "data": Object {
-                    "type": 3,
-                  },
-                  "documentation": Object {
-                    "kind": "markdown",
-                    "value": "Variable: **RESET** - *defined in extension.inc*",
-                  },
-                  "kind": 6,
-                  "label": "RESET",
-                },
-              ]
-          `)
+        Array [
+          Object {
+            "data": Object {
+              "type": 3,
+            },
+            "documentation": undefined,
+            "kind": 6,
+            "label": "BOLD",
+          },
+          Object {
+            "data": Object {
+              "type": 3,
+            },
+            "documentation": Object {
+              "kind": "markdown",
+              "value": "Variable: **RED** - *defined in extension.inc*",
+            },
+            "kind": 6,
+            "label": "RED",
+          },
+          Object {
+            "data": Object {
+              "type": 3,
+            },
+            "documentation": Object {
+              "kind": "markdown",
+              "value": "Variable: **GREEN** - *defined in extension.inc*",
+            },
+            "kind": 6,
+            "label": "GREEN",
+          },
+          Object {
+            "data": Object {
+              "type": 3,
+            },
+            "documentation": Object {
+              "kind": "markdown",
+              "value": "Variable: **BLUE** - *defined in extension.inc*",
+            },
+            "kind": 6,
+            "label": "BLUE",
+          },
+          Object {
+            "data": Object {
+              "type": 3,
+            },
+            "documentation": Object {
+              "kind": "markdown",
+              "value": "Variable: **RESET** - *defined in extension.inc*",
+            },
+            "kind": 6,
+            "label": "RESET",
+          },
+          Object {
+            "data": Object {
+              "type": 3,
+            },
+            "documentation": Object {
+              "kind": "markdown",
+              "value": "Variable: **FILE_PATH** - *defined in extension.inc*",
+            },
+            "kind": 6,
+            "label": "FILE_PATH",
+          },
+        ]
+      `)
     })
   })
 
